@@ -1,4 +1,6 @@
-from typing import List, Dict, Union
+from typing import List, Dict, Union, TypeVar
+
+PersonType = TypeVar("PersonType", bound="Person")
 
 
 class Person:
@@ -19,11 +21,11 @@ class Person:
         self.has_no_match: bool = False
 
     @property
-    def connections(self) -> List["Person"]:
+    def connections(self) -> List[PersonType]:
         return self._connections
 
     @connections.setter
-    def connections(self, new_connection: "Person"):
+    def connections(self, new_connection: PersonType):
         if len(self._connections) < 3:
             self._connections.append(new_connection)
         else:
@@ -59,8 +61,16 @@ class Person:
                     output[f"match {i + 1} {key}"] = value
         return output
 
+    def to_dict_for_export(self, depth=1) -> dict:
+        """
+        This method converts the class into a dictionary suitable for export. It might be useful if you don't want
+        every attribute on the model exposed, or if there's some mapping you need to do - for example, 'grade' might be
+        'rank' in your organisation. By default, this method just calls `to_dict_for_output`
+        """
+        return self.to_dict_for_output(depth)
+
     def class_name(self):
         return self.__class__.__name__.lower()
 
-    def __eq__(self, other: "Person"):
+    def __eq__(self, other: PersonType):
         return self.email == other.email
